@@ -1,13 +1,13 @@
 package File::Spec::OS2;
 
 use strict;
-use vars qw(@ISA $VERSION);
+use Cwd ();
 require File::Spec::Unix;
 
-$VERSION = '3.33';
-$VERSION = eval $VERSION;
+our $VERSION = '3.75';
+$VERSION =~ tr/_//d;
 
-@ISA = qw(File::Spec::Unix);
+our @ISA = qw(File::Spec::Unix);
 
 sub devnull {
     return "/dev/nul";
@@ -30,16 +30,13 @@ sub path {
     return @path;
 }
 
-sub _cwd {
-    # In OS/2 the "require Cwd" is unnecessary bloat.
-    return Cwd::sys_cwd();
-}
-
-my $tmpdir;
 sub tmpdir {
-    return $tmpdir if defined $tmpdir;
+    my $cached = $_[0]->_cached_tmpdir(qw 'TMPDIR TEMP TMP');
+    return $cached if defined $cached;
     my @d = @ENV{qw(TMPDIR TEMP TMP)};	# function call could autovivivy
-    $tmpdir = $_[0]->_tmpdir( @d, '/tmp', '/'  );
+    $_[0]->_cache_tmpdir(
+	$_[0]->_tmpdir( @d, '/tmp', '/' ), qw 'TMPDIR TEMP TMP'
+    );
 }
 
 sub catdir {
@@ -74,15 +71,15 @@ sub splitpath {
     my ($self,$path, $nofile) = @_;
     my ($volume,$directory,$file) = ('','','');
     if ( $nofile ) {
-        $path =~
-            m{^( (?:[a-zA-Z]:|(?:\\\\|//)[^\\/]+[\\/][^\\/]+)? )
+        $path =~ 
+            m{^( (?:[a-zA-Z]:|(?:\\\\|//)[^\\/]+[\\/][^\\/]+)? ) 
                  (.*)
              }xs;
         $volume    = $1;
         $directory = $2;
     }
     else {
-        $path =~
+        $path =~ 
             m{^ ( (?: [a-zA-Z]: |
                       (?:\\\\|//)[^\\/]+[\\/][^\\/]+
                   )?
@@ -117,7 +114,7 @@ sub catpath {
 
     $volume .= $directory ;
 
-    # If the volume is not just A:, make sure the glue separator is
+    # If the volume is not just A:, make sure the glue separator is 
     # there, reusing whatever separator is first in the $volume if possible.
     if ( $volume !~ m@^[a-zA-Z]:\Z(?!\n)@s &&
          $volume =~ m@[^\\/]\Z(?!\n)@      &&
@@ -146,7 +143,7 @@ sub abs2rel {
 
     # Figure out the effective $base and clean it up.
     if ( !defined( $base ) || $base eq '' ) {
-	$base = $self->_cwd();
+	$base = Cwd::getcwd();
     } elsif ( ! $self->file_name_is_absolute( $base ) ) {
         $base = $self->rel2abs( $base ) ;
     } else {
@@ -162,9 +159,9 @@ sub abs2rel {
     my @pathchunks = $self->splitdir( $path_directories );
     my @basechunks = $self->splitdir( $base_directories );
 
-    while ( @pathchunks &&
-            @basechunks &&
-            lc( $pathchunks[0] ) eq lc( $basechunks[0] )
+    while ( @pathchunks && 
+            @basechunks && 
+            lc( $pathchunks[0] ) eq lc( $basechunks[0] ) 
           ) {
         shift @pathchunks ;
         shift @basechunks ;
@@ -175,7 +172,7 @@ sub abs2rel {
     $base_directories = CORE::join( '/', @basechunks );
 
     # $base_directories now contains the directories the resulting relative
-    # path must ascend out of before it can descend to $path_directory.  So,
+    # path must ascend out of before it can descend to $path_directory.  So, 
     # replace all names with $parentDir
 
     #FA Need to replace between backslashes...
@@ -191,8 +188,8 @@ sub abs2rel {
         $path_directories = "$base_directories$path_directories" ;
     }
 
-    return $self->canonpath(
-        $self->catpath( "", $path_directories, $path_file )
+    return $self->canonpath( 
+        $self->catpath( "", $path_directories, $path_file ) 
     ) ;
 }
 
@@ -203,7 +200,7 @@ sub rel2abs {
     if ( ! $self->file_name_is_absolute( $path ) ) {
 
         if ( !defined( $base ) || $base eq '' ) {
-	    $base = $self->_cwd();
+	    $base = Cwd::getcwd();
         }
         elsif ( ! $self->file_name_is_absolute( $base ) ) {
             $base = $self->rel2abs( $base ) ;
@@ -218,9 +215,9 @@ sub rel2abs {
         my ( $base_volume, $base_directories ) =
             $self->splitpath( $base, 1 ) ;
 
-        $path = $self->catpath(
-            $base_volume,
-            $self->catdir( $base_directories, $path_directories ),
+        $path = $self->catpath( 
+            $base_volume, 
+            $self->catdir( $base_directories, $path_directories ), 
             $path_file
         ) ;
     }
